@@ -1,10 +1,10 @@
 /* extern.h: This include file declares all symbols exported by the interpreter
  * kernel that may be used by applications or extensions.
  *
- * $Id: extern.h 252 2004-08-09 20:05:25Z sam $
+ * $Id$
  *
  * Copyright 1990, 1991, 1992, 1993, 1994, 1995, Oliver Laumann, Berlin
- * Copyright 2002, 2003 Sam Hocevar <sam@zoy.org>, Paris
+ * Copyright 2002, 2003 Sam Hocevar <sam@hocevar.net>, Paris
  *
  * This software was derived from Elk 1.2, which was Copyright 1987, 1988,
  * 1989, Nixdorf Computer AG and TELES GmbH, Berlin (Elk 1.2 has been written
@@ -366,8 +366,11 @@ extern Object P_Macro (Object);
 extern Object P_Macro_Body (Object);
 extern Object P_Macro_Expand (Object);
 extern Object P_Primitivep (Object);
+extern Object P_Primitive_To_String (Object);
 extern Object P_Compoundp (Object);
+extern Object P_Compound_To_String (Object);
 extern Object P_Macrop (Object);
+extern Object P_Macro_To_String (Object);
 extern void Check_Procedure (Object);
 
 /* Delay and force
