@@ -1,9 +1,9 @@
 /* display.c
  *
- * $Id: display.c 91 2003-09-04 14:32:13Z sam $
+ * $Id$
  *
  * Copyright 1990, 1991, 1992, 1993, 1994, 1995, Oliver Laumann, Berlin
- * Copyright 2002, 2003 Sam Hocevar <sam@zoy.org>, Paris
+ * Copyright 2002, 2003 Sam Hocevar <sam@hocevar.net>, Paris
  *
  * This software was derived from Elk 1.2, which was Copyright 1987, 1988,
  * 1989, Nixdorf Computer AG and TELES GmbH, Berlin (Elk 1.2 has been written
@@ -43,7 +43,8 @@ Generic_Equal (Display, DISPLAY, dpy)
 
 static int Display_Print (Object d, Object port,
                           int raw, int depth, int length) {
-    Printf (port, "#[display %lu %s]", (unsigned)DISPLAY(d)->dpy,
+    Printf (port, "#[display %lu %s]",
+        (unsigned long)(uintptr_t)DISPLAY(d)->dpy,
         DisplayString (DISPLAY(d)->dpy));
     return 0;
 }
