@@ -1,9 +1,9 @@
 /* gcontext.c
  *
- * $Id: gcontext.c 91 2003-09-04 14:32:13Z sam $
+ * $Id$
  *
  * Copyright 1990, 1991, 1992, 1993, 1994, 1995, Oliver Laumann, Berlin
- * Copyright 2002, 2003 Sam Hocevar <sam@zoy.org>, Paris
+ * Copyright 2002, 2003 Sam Hocevar <sam@hocevar.net>, Paris
  *
  * This software was derived from Elk 1.2, which was Copyright 1987, 1988,
  * 1989, Nixdorf Computer AG and TELES GmbH, Berlin (Elk 1.2 has been written
@@ -36,7 +36,7 @@ Generic_Predicate (Gc)
 
 Generic_Equal_Dpy (Gc, GCONTEXT, gc)
 
-Generic_Print (Gc, "#[gcontext %lu]", GCONTEXT(x)->gc)
+Generic_Print (Gc, "#[gcontext %lu]", (unsigned int)(uintptr_t)GCONTEXT(x)->gc)
 
 Generic_Get_Display (Gc, GCONTEXT)
 
