@@ -1,9 +1,9 @@
 /* context.c
  *
- * $Id: context.c 137 2003-09-09 23:13:50Z sam $
+ * $Id$
  *
  * Copyright 1990, 1991, 1992, 1993, 1994, 1995, Oliver Laumann, Berlin
- * Copyright 2002, 2003 Sam Hocevar <sam@zoy.org>, Paris
+ * Copyright 2002, 2003 Sam Hocevar <sam@hocevar.net>, Paris
  *
  * This software was derived from Elk 1.2, which was Copyright 1987, 1988,
  * 1989, Nixdorf Computer AG and TELES GmbH, Berlin (Elk 1.2 has been written
@@ -50,7 +50,7 @@ Generic_Predicate (Context)
 
 Generic_Equal (Context, CONTEXT, context)
 
-Generic_Print (Context, "#[context %lu]", POINTER(x))
+Generic_Print (Context, "#[context %lu]", (unsigned int)(uintptr_t)POINTER(x))
 
 static Object Internal_Make_Context (int finalize, XtAppContext context) {
     Object c;
