@@ -1,9 +1,9 @@
 /* identifier.c
  *
- * $Id: identifier.c 93 2003-09-04 15:30:04Z sam $
+ * $Id$
  *
  * Copyright 1990, 1991, 1992, 1993, 1994, 1995, Oliver Laumann, Berlin
- * Copyright 2002, 2003 Sam Hocevar <sam@zoy.org>, Paris
+ * Copyright 2002, 2003 Sam Hocevar <sam@hocevar.net>, Paris
  *
  * This software was derived from Elk 1.2, which was Copyright 1987, 1988,
  * 1989, Nixdorf Computer AG and TELES GmbH, Berlin (Elk 1.2 has been written
@@ -37,7 +37,8 @@ static int Identifier_Equal (Object x, Object y) {
     return p->type == q->type && p->val == q->val && !p->free && !q->free;
 }
 
-Generic_Print (Identifier, "#[identifier %lu]", POINTER(x))
+Generic_Print (Identifier, "#[identifier %lu]",
+               (unsigned int)(uintptr_t)POINTER(x))
 
 Object Make_Id (int type, XtPointer val, int num) {
     Object i;
