@@ -1,9 +1,9 @@
 /* widget.c
  *
- * $Id: widget.c 158 2003-09-15 12:53:36Z sam $
+ * $Id$
  *
  * Copyright 1990, 1991, 1992, 1993, 1994, 1995, Oliver Laumann, Berlin
- * Copyright 2002, 2003 Sam Hocevar <sam@zoy.org>, Paris
+ * Copyright 2002, 2003 Sam Hocevar <sam@hocevar.net>, Paris
  *
  * This software was derived from Elk 1.2, which was Copyright 1987, 1988,
  * 1989, Nixdorf Computer AG and TELES GmbH, Berlin (Elk 1.2 has been written
@@ -30,15 +30,13 @@
 
 #include "xt.h"
 
-extern void XtManageChildren(), XtUnmanageChildren();
-
-static Object P_Destroy_Widget();
+static Object P_Destroy_Widget(Object);
 
 Generic_Predicate (Widget)
 
 Generic_Equal (Widget, WIDGET, widget)
 
-Generic_Print (Widget, "#[widget %lu]", POINTER(x))
+Generic_Print (Widget, "#[widget %lu]", (unsigned int)(uintptr_t)POINTER(x))
 
 static Object Internal_Make_Widget (int finalize, Widget widget) {
     Object w;
